package applications.dns;

import java.sql.*;
import applications.basics.t_connect;

public class CreateDB {

    private  ResultSet sqlresult;
    private  t_connect con;
    private  String message;
    
    String host;
  
    /**
       * Get the value of host.
       * @return Value of host.
       */
    public String getHost() {return host;}
    
    /**
       * Set the value of host.
       * @param v  Value to assign to host
       */
    public void setHost(String  v) {this.host = v;}
    
    String user;
    
    /**
       * Get the value of user.
       * @return Value of user.
       */
    public String getUser() {return user;}
    
    /**
       * Set the value of user.
       * @param v  Value to assign to user.
       */
    public void setUser(String  v) {this.user = v;}
    
    String password;
    
    /**
       * Get the value of password.
       * @return Value of password.
       */
    public String getPassword() {return password;}
    
    /**
       * Set the value of password.
       * @param v  Value to assign to password.
       */
    public void setPassword(String  v) {this.password = v;}


    String database;
    
    /**
       * Get the value of database.
       * @return Value of database.
       */
    public String getDatabase() {return database;}
    
    /**
       * Set the value of database.
       * @param v  Value to assign to database.
       */
    public void setDatabase(String  v) {this.database = v;}


    public CreateDB(String host, String user, String password) {

	setDatabase("dns");

	setHost(host);
	setUser(user);
	setPassword(password);
	clearMessage();

	con = new t_connect(getHost(), getUser(), getPassword(), getDatabase());
	if (con.getError() != null) {
	    message("Connection Error: "+ con.getError());
	}	


	message(sqlStatement("CREATE TABLE alias ( " +
			     "domain varchar(25) NOT NULL, " +
			     "hostname varchar(25) NOT NULL, " +
			     "alias varchar(25) NOT NULL)"));
	message(sqlStatement("CREATE UNIQUE INDEX aliasIDX1 on alias (domain,hostname, alias)"));


	message(sqlStatement("CREATE TABLE domain ( " +
			    "name varchar(25) NOT NULL, " +
			    "responsible varchar(25) DEFAULT 'root' NOT NULL, " +
			    "serialnumber int(11) DEFAULT '1' NOT NULL, " +
			    "refresh int(11) DEFAULT '10800' NOT NULL, " +
			    "retry int(11) DEFAULT '3600' NOT NULL, " + 
			    "expire int(11) DEFAULT '604800' NOT NULL, " +
			    "minTTL int(11) DEFAULT '86400' NOT NULL, " + 
			    "network char(15) DEFAULT '192.168.1', " +
			    "PRIMARY KEY (name) )"));

	message(sqlStatement("CREATE UNIQUE INDEX domainIDX1 on domain (name)"));

	message(sqlStatement("CREATE TABLE host ( " +
			     "domain varchar(25) NOT NULL, " +
			     "hostname varchar(25) NOT NULL, " +
			     "ip varchar(15) NOT NULL, " +
			     "wksTCP varchar(25)," +
			     "wksUDP varchar(25) )"));

	message(sqlStatement("CREATE UNIQUE INDEX hostIDX1 on host (domain, hostname)"));

	message(sqlStatement("CREATE TABLE mailexchange ( " +
			     "domain varchar(25) NOT NULL, " +
			     "mailexchange varchar(25) NOT NULL, " +
			     "priority varchar(3) DEFAULT '10' NOT NULL)"));

	message(sqlStatement("CREATE INDEX mxIDX1 on mailexchange (domain)"));

	message(sqlStatement("CREATE TABLE nameserver ( " +
			     "domain varchar(25) NOT NULL, " +
			     "nameserver varchar(25) NOT NULL)"));
	message(sqlStatement("CREATE UNIQUE INDEX nsIDX1 on nameserver (domain, nameserver)"));

	message(sqlStatement("CREATE TABLE hostinformation ( " +
			     "domain varchar(25) NOT NULL, " +
			     "hostname varchar(25) NOT NULL, " +
			     "os varchar(25) NOT NULL) " ));
	message(sqlStatement("CREATE INDEX hinfoIDX1 on hostinformation (domain)"));
	message(sqlStatement("CREATE INDEX hinfoIDX2 on hostinformation (domain, hostname)"));


	message(sqlStatement("create table forwarder (" +
			     "domain varchar(25) NOT NULL, " +
			     "hostname varchar(25) not null"));
        message(sqlStatement("create index forwarderidx1 on forwarder (domain,hostname)"));

        con.close(); 	


    }


    private void message(String m) { message = message + "\n" + m; }
    public String getMessage() { return message; }
    public void clearMessage() { message = ""; }


    private String sqlStatement(String q) {
	
        try {
	    int records = con.stmt.executeUpdate(q);
	} catch (Exception e) {
	    return e.getMessage().toString();
	}
	return "";
    }


    public static void main(String args[]) {

	System.out.println("\nThis creates the DB needed for the DNS-Tool\n");
	if (args.length !=3 ) {
            System.out.println("Syntax: java applications.dns.CreateDB host user password");
	    System.exit(0);
	}
	CreateDB cdb = new CreateDB(args[0], args[1], args[2]);
	System.out.println(cdb.getMessage());
    }
}
